@@ -1,7 +1,7 @@
 <?php
     /* change_pass
      *
-     * $Id: options.php,v 1.2 2003/09/26 02:33:10 indiri69 Exp $
+     * $Id: options.php,v 1.4 2003/12/07 21:45:04 indiri69 Exp $
      */
 
     define('SM_PATH', '../../');
@@ -138,8 +138,7 @@ function change_pass_go($password, $debug) {
     }
     $pop_socket = fsockopen($imapServerAddress, 106, $errno, $errstr);
     if (!$pop_socket) {
-        $messages[] = _("ERROR:") .
-                     "$errstr ($errno)";
+        $messages[] = _("ERROR:") .  "$errstr ($errno)";
         return $messages;
     }
 
@@ -158,7 +157,7 @@ function change_pass_go($password, $debug) {
 
     fputs($pop_socket, "pass $password\r\n");
     change_pass_readfb($pop_socket, $result, $messages, $debug);
-    if(!preg_match('/^2\d\d/', $result) ) {
+    if(!preg_match('/^[23]\d\d/', $result) ) {
         change_pass_closeport($pop_socket, $messages, $debug);
         return $messages;
     }
@@ -166,26 +165,18 @@ function change_pass_go($password, $debug) {
     fputs($pop_socket, "newpass $cp_newpass\r\n");
     change_pass_readfb($pop_socket, $result, $messages, $debug);
     change_pass_closeport($pop_socket, $messages, $debug);
-    if(!preg_match('/^2\d\d/', $result) )
+    if(!preg_match('/^2\d\d/', $result) ) {
         return $messages;
+    }
+
+    $messages[] = _("Password changed successfully.");
 
-    //if ($debug) {
-        $messages[] = _("Password changed successfully.");
-    //}
     // Write new cookies for the password
     $onetimepad = OneTimePadCreate(strlen($cp_newpass));
     $key = OneTimePadEncrypt($cp_newpass, $onetimepad);
     sqsession_register($onetimepad, 'onetimepad');
     setcookie('key', $key, 0, $base_uri);
 
-    // Automatically forward back to the options screen if correct
-    /*
-    if ($debug == 0) {
-        header('Location: ' . $base_uri
-               . 'src/options.php?plugin_change_pass=true');
-       exit(0);
-    }
-    */
     return $messages;
 }
 ?>
